@@ -1,4 +1,4 @@
-dd_KI_ML = function(brtsM,brtsS,tsplit,initparsopt=c(0.5,0.1,2*(1+length(brtsM)),2*(1+length(brtsS)),(tsplit + max(brtsS))/2),parsfix = NULL,idparsopt=c(1:3,6:7),idparsfix=NULL,idparsnoshift=(1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)],res=10*(1 + length(c(brtsM,brtsS))),ddmodel=1,missnumspec=0,cond = TRUE)
+dd_KI_ML = function(brtsM,brtsS,tsplit,initparsopt=c(0.5,0.1,2*(1+length(brtsM)),2*(1+length(brtsS)),(tsplit + max(brtsS))/2),parsfix = NULL,idparsopt=c(1:3,6:7),idparsfix=NULL,idparsnoshift=(1:7)[c(-idparsopt,(-1)^(length(idparsfix) != 0) * idparsfix)],res=10*(1 + length(c(brtsM,brtsS)) + missnumspec),ddmodel=1,missnumspec=0,cond = TRUE)
 {
 # brtsM, brtsS = branching times of main clade and subclade (positive, from present to past)
 # - max(brts) = crown age
